# Gauss-Legendre quadrature
# generate abscissae and weights using Golub-Welsch algorithm

from numpy import *
#from scipy import integrate

from quad_test import *

class gauss_legendre_formula:
    def __init__(self, N):
        j = arange(1, N)
        beta = j * sqrt(1.0/((2*j-1.0)*(2*j+1.0)))
        B = zeros((N-1, N+1))
        B[:,1] = beta
        B[:,-1] = beta
        A = resize(B, (N, N))
        ew, ev = linalg.eig(A)
        ind = argsort(ew)
        self.x = take(ew, ind)
        self.w = 2 * take(ev[0,:], ind)**2

    def integrate_base(self, f):
        return sum(self.w * f(self.x))

    def integrate(self, f, a=-1, b=1):
        if a == -1 and b == 1:
            return self.integrate_base(f)
        else:
            d = (b - a)/2.0
            def g(x):
                return f(a + (x + 1.0)*d)
            return self.integrate_base(g) * d

if __name__ == "__main__":
    gl5 = gauss_legendre_formula(5)

    print gl5.x
    print gl5.w

    def p0(x):
        return 1.0
    def p1(x):
        return x

    print gl5.integrate(p1)
    gl20 = gauss_legendre_formula(20)
    for f in [ semicirc, sinus ]:
        print gl20.integrate(f) - f.exact



